@@ -6,6 +6,7 @@
 
 import inspect
 import json
+import logging
 import time
 import types
 from datetime import datetime
@@ -57,6 +58,7 @@ class BaseHandler(RequestHandler):
         重写父类get请求处理方法，直接调用post方法统一处理
         :return:
         """
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
         await self.request_handler()
 
     async def post(self):
